@@ -1,22 +1,14 @@
-/***************************************************************************
- *  Copyright (C) 2006 by Carsten Niehaus <cniehaus@kde.org>
- *  Copyright (C) 2007-2008 by Marcus D. Hanwell <marcus@cryos.org>
- *  Copyright (C) 2016 by Andreas Cord-Landwehr <cordlandwehr@kde.org>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 Carsten Niehaus <cniehaus@kde.org>
+    SPDX-FileCopyrightText: 2007-2008 Marcus D. Hanwell <marcus@cryos.org>
+    SPDX-FileCopyrightText: 2016 Andreas Cord-Landwehr <cordlandwehr@kde.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "iowrapper.h"
 
-#include <iostream>
 #include <fstream>
+#include <iostream>
 
 #include <avogadro/core/molecule.h>
 #include <avogadro/io/cmlformat.h>
@@ -35,22 +27,20 @@ std::unique_ptr<Avogadro::Core::Molecule> IoWrapper::readMolecule(const QString
 {
     std::ifstream inFileStream(QFile::encodeName(filename).constData());
     if (!inFileStream) {
-        QMessageBox::warning(nullptr, i18n("Problem while opening the file"),
-                           i18n("Cannot open the specified file."));
+        QMessageBox::warning(nullptr, i18n("Problem while opening the file"), i18n("Cannot open the specified file."));
         return nullptr;
     }
 
     auto mol = std::make_unique<Avogadro::Core::Molecule>();
     auto format = getFileReader(QFileInfo(filename).suffix());
 
-    if (!format){
+    if (!format) {
         qCritical() << "Could not initialize file reader for file " << filename;
         return nullptr;
     }
 
     if (!format->read(inFileStream, *mol)) {
-        qCritical() << "Could not read file " << filename << "; Error message: "
-            << QString().fromStdString(format->error());
+        qCritical() << "Could not read file " << filename << "; Error message: " << QString().fromStdString(format->error());
         return nullptr;
     }
 
