@@ -5,9 +5,9 @@
 
 #include "moleculeparser.h"
 
-#include <ctype.h>
+#include <cctype>
 
-#include <QDebug>
+#include "kalzium_libscience_debug.h"
 #include <QFile>
 #include <QStandardPaths>
 
@@ -19,13 +19,11 @@ ElementCountMap::ElementCountMap()
     m_map.clear();
 }
 
-ElementCountMap::~ElementCountMap()
-{
-}
+ElementCountMap::~ElementCountMap() = default;
 
 ElementCount *ElementCountMap::search(Element *_element)
 {
-    foreach (ElementCount *c, m_map) {
+    for (ElementCount *c : std::as_const(m_map)) {
         if (c->element() == _element) {
             return c;
         }
@@ -36,17 +34,17 @@ ElementCount *ElementCountMap::search(Element *_element)
 
 void ElementCountMap::add(ElementCountMap &_map)
 {
-    foreach (ElementCount *c, _map.m_map) {
+    for (ElementCount *c : std::as_const(_map.m_map)) {
         add(c->m_element, c->m_count);
     }
 }
 
-QList<Element*> ElementCountMap::elements()
+QList<Element *> ElementCountMap::elements() const
 {
-    QList<Element*> list;
+    QList<Element *> list;
 
-    foreach (ElementCount* c, m_map) {
-        Element* e = c->m_element;
+    for (ElementCount *c : std::as_const(m_map)) {
+        Element *e = c->m_element;
         if (!list.contains(e)) {
             list << e;
         }
@@ -69,21 +67,23 @@ void ElementCountMap::add(Element *_element, int _count)
 
 void ElementCountMap::multiply(int _factor)
 {
-  foreach (ElementCount * count, m_map) {
-      count->multiply(_factor);
-  }
+    for (ElementCount *count : std::as_const(m_map)) {
+        count->multiply(_factor);
+    }
 }
 
 // ================================================================
 //                    class MoleculeParser
 
-MoleculeParser::MoleculeParser( const QList<Element*> &list) : Parser()
+MoleculeParser::MoleculeParser(const QList<Element *> &list)
+    : Parser()
 {
     m_elementList = list;
     m_aliasList = new QSet<QString>;
 }
 
-MoleculeParser::MoleculeParser(const QString &_str) : Parser(_str)
+MoleculeParser::MoleculeParser(const QString &_str)
+    : Parser(_str)
 {
     m_aliasList = new QSet<QString>;
 }
@@ -100,16 +100,14 @@ MoleculeParser::~MoleculeParser()
 //
 // This method also acts as the main loop.
 
-bool MoleculeParser::weight(const QString   &_shortMoleculeString,
-                            double          *_resultMass,
-                            ElementCountMap *_resultMap)
+bool MoleculeParser::weight(const QString &_shortMoleculeString, double *_resultMass, ElementCountMap *_resultMap)
 {
     if (_shortMoleculeString.isEmpty()) {
         return false;
     }
     // Clear the list of aliases and start filling it again.
 
-    m_aliasList -> clear();
+    m_aliasList->clear();
     QString _moleculeString;
     // Clear the result variables and set m_error to false
     _resultMap->clear();
@@ -118,9 +116,9 @@ bool MoleculeParser::weight(const QString   &_shortMoleculeString,
 
     // Expand the molecule string
     // Example : MeOH -> (CH3)OH
-    qDebug() << _shortMoleculeString << "is going to be expanded";
+    qCDebug(KALZIUM_LIBSCIENCE_LOG) << _shortMoleculeString << "is going to be expanded";
     _moleculeString = expandFormula(_shortMoleculeString);
-    qDebug() << _moleculeString << "is the expanded string";
+    qCDebug(KALZIUM_LIBSCIENCE_LOG) << _moleculeString << "is the expanded string";
 
     // Now set the expanded string
     // Initialize the parsing process, and parse te molecule.
@@ -131,7 +129,7 @@ bool MoleculeParser::weight(const QString   &_shortMoleculeString,
         return false;
     }
 
-    if (m_error) {//there was an error in the input...
+    if (m_error) { // there was an error in the input...
         return false;
     }
 
@@ -145,20 +143,18 @@ QSet<QString> MoleculeParser::aliasList()
 // ----------------------------------------------------------------
 //            helper methods for the public methods
 
-
 // Parse a submolecule.  This is a list of terms.
 //
 
-bool MoleculeParser::parseSubmolecule(double          *_resultMass,
-                                      ElementCountMap *_resultMap)
+bool MoleculeParser::parseSubmolecule(double *_resultMass, ElementCountMap *_resultMap)
 {
-    double          subMass = 0.0;
+    double subMass = 0.0;
     ElementCountMap subMap;
 
     *_resultMass = 0.0;
     _resultMap->clear();
     while (parseTerm(&subMass, &subMap)) {
-        //qDebug() << "Parsed a term, weight = " << subresult;
+        // qCDebug(KALZIUM_LIBSCIENCE_LOG) << "Parsed a term, weight = " << subresult;
 
         // Add the mass and composition of the submolecule to the total.
         *_resultMass += subMass;
@@ -168,26 +164,24 @@ bool MoleculeParser::parseSubmolecule(double          *_resultMass,
     return true;
 }
 
-
 // Parse a term within the molecule, i.e. a single atom or a
 // submolecule within parenthesis followed by an optional number.
 // Examples: Bk, Mn2, (COOH)2
 //
-// Return true if correct, otherwise return false.  
+// Return true if correct, otherwise return false.
 
 // If correct, the mass of the term is returned in *_resultMass, and
 // the flattened composition of the molecule in *_resultMap.
 //
 
-bool MoleculeParser::parseTerm(double          *_resultMass,
-                               ElementCountMap *_resultMap)
+bool MoleculeParser::parseTerm(double *_resultMass, ElementCountMap *_resultMap)
 {
     *_resultMass = 0.0;
     _resultMap->clear();
 
     if (nextToken() == ELEMENT_TOKEN) {
-        //qDebug() << "Parsed an element: " << m_elementVal->symbol();
-        *_resultMass = m_elementVal->dataAsVariant( ChemicalDataObject::mass ).toDouble();
+        // qCDebug(KALZIUM_LIBSCIENCE_LOG) << "Parsed an element: " << m_elementVal->symbol();
+        *_resultMass = m_elementVal->dataAsVariant(ChemicalDataObject::mass).toDouble();
         _resultMap->add(m_elementVal, 1);
 
         getNextToken();
@@ -199,7 +193,7 @@ bool MoleculeParser::parseTerm(double          *_resultMass,
 
         // Must end in a ")".
         if (nextToken() == ')') {
-            //qDebug() << "Parsed a submolecule. weight = " << *_result;
+            // qCDebug(KALZIUM_LIBSCIENCE_LOG) << "Parsed a submolecule. weight = " << *_result;
             getNextToken();
         } else {
             return false;
@@ -211,7 +205,7 @@ bool MoleculeParser::parseTerm(double          *_resultMass,
 
     // Optional number.
     if (nextToken() == INT_TOKEN) {
-        //qDebug() << "Parsed a number: " << intVal();
+        // qCDebug(KALZIUM_LIBSCIENCE_LOG) << "Parsed a number: " << intVal();
 
         *_resultMass *= intVal();
         _resultMap->multiply(intVal());
@@ -219,7 +213,7 @@ bool MoleculeParser::parseTerm(double          *_resultMass,
         getNextToken();
     }
 
-    qDebug() << "Weight of term = " << *_resultMass;
+    qCDebug(KALZIUM_LIBSCIENCE_LOG) << "Weight of term = " << *_resultMass;
     return true;
 }
 
@@ -233,7 +227,7 @@ int MoleculeParser::getNextToken()
     QString name;
 
 #if 0
-    qDebug() << "getNextToken(): Next character = "
+    qCDebug(KALZIUM_LIBSCIENCE_LOG) << "getNextToken(): Next character = "
           << nextChar() << endl;
 #endif
 
@@ -243,8 +237,8 @@ int MoleculeParser::getNextToken()
         getNextChar();
 
         if ('a' <= nextChar() && nextChar() <= 'z') {
-                name.append(char(nextChar()));
-                getNextChar();
+            name.append(char(nextChar()));
+            getNextChar();
         }
 
         // Look up the element from the name..
@@ -264,34 +258,34 @@ int MoleculeParser::getNextToken()
 // ----------------------------------------------------------------
 //                          private methods
 
-Element *MoleculeParser::lookupElement(const QString& _name)
+Element *MoleculeParser::lookupElement(const QString &_name)
 {
-    qDebug() << "looking up " << _name;
+    qCDebug(KALZIUM_LIBSCIENCE_LOG) << "looking up " << _name;
 
-    foreach (Element* e, m_elementList) {
+    for (Element *e : std::as_const(m_elementList)) {
         if (e->dataAsVariant(ChemicalDataObject::symbol) == _name) {
-            qDebug() << "Found element " << _name;
+            qCDebug(KALZIUM_LIBSCIENCE_LOG) << "Found element " << _name;
             return e;
         }
     }
 
-    //if there is an error make m_error true.
+    // if there is an error make m_error true.
     m_error = true;
 
-    qDebug() << "no such element!: " << _name;
+    qCDebug(KALZIUM_LIBSCIENCE_LOG) << "no such element!: " << _name;
 
     return nullptr;
 }
 
-QString MoleculeParser::expandFormula( const QString& _shortString)
+QString MoleculeParser::expandFormula(const QString &_shortString)
 {
-    QString _fullString;       // the expanded string that will be returned
+    QString _fullString; // the expanded string that will be returned
     QString::const_iterator i; // iterator
-    QString temp;              // a temporary string that will contain a single element/group
-    QString expandedTerm;      // expansion of a particular term
+    QString temp; // a temporary string that will contain a single element/group
+    QString expandedTerm; // expansion of a particular term
 
     // Go through all letters in the string.
-    for (i = _shortString.constBegin(); i != _shortString.constEnd(); ) {
+    for (i = _shortString.constBegin(); i != _shortString.constEnd();) {
         temp = QLatin1String("");
 
         // If a capital letter was found
@@ -310,8 +304,8 @@ QString MoleculeParser::expandFormula( const QString& _shortString)
                 _fullString += temp;
             } else if (!((expandedTerm = expandTerm(temp)).isEmpty())) {
                 // If an expansion was made, return the expansion
-                qDebug() << "expanded" << temp << "to" << expandedTerm;
-                _fullString += '('+expandedTerm+')';
+                qCDebug(KALZIUM_LIBSCIENCE_LOG) << "expanded" << temp << "to" << expandedTerm;
+                _fullString += '(' + expandedTerm + ')';
             } else { // invalid term, append it. (Validation is done later anyway.)
                 _fullString += temp;
             }
@@ -322,9 +316,9 @@ QString MoleculeParser::expandFormula( const QString& _shortString)
             _fullString += ')';
             ++i;
         } else if (*i == '#') { // If # is found, we have a short-form eg #EDTA#
-            ++i;        // go to the next character
+            ++i; // go to the next character
             // Get the term between # and #
-            while (*i != '#' && i != _shortString.constEnd() ) {
+            while (*i != '#' && i != _shortString.constEnd()) {
                 temp += *i;
                 ++i;
             }
@@ -347,7 +341,7 @@ QString MoleculeParser::expandFormula( const QString& _shortString)
         } else { // invalid character, return it, validation is done again later
             _fullString += *i;
             ++i;
-            qDebug() << *i << "invalid character!";
+            qCDebug(KALZIUM_LIBSCIENCE_LOG) << *i << "invalid character!";
         }
     }
 
@@ -356,11 +350,10 @@ QString MoleculeParser::expandFormula( const QString& _shortString)
     return _fullString;
 }
 
-QString MoleculeParser::expandTerm (const QString& _group)
+QString MoleculeParser::expandTerm(const QString &_group)
 {
-
-    QString shortForm, fullForm;    // short form (symbol) and full form (expansion)
-    QString temp;                    // A temporary QString used in Regular expressions
+    QString shortForm, fullForm; // short form (symbol) and full form (expansion)
+    QString temp; // A temporary QString used in Regular expressions
 
     // Search in User defined aliases.
     QString fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("libkdeedu/data/symbols2.csv"));
@@ -368,7 +361,7 @@ QString MoleculeParser::expandTerm (const QString& _group)
 
     // Check file validity
     if (!(!file.open(QIODevice::ReadOnly | QIODevice::Text))) {
-        qDebug() << fileName << " opened";
+        qCDebug(KALZIUM_LIBSCIENCE_LOG) << fileName << " opened";
         QTextStream in(&file);
 
         // Get all shortForms and fullForms in the file.
@@ -376,7 +369,7 @@ QString MoleculeParser::expandTerm (const QString& _group)
             QString line = in.readLine();
             shortForm = line.section(',', 0, 0);
             shortForm.remove(QChar('\"'));
-            fullForm  = line.section(',', 1, 1);
+            fullForm = line.section(',', 1, 1);
             fullForm.remove(QChar('\"'));
 
             // If short term is found, return fullForm
@@ -386,17 +379,17 @@ QString MoleculeParser::expandTerm (const QString& _group)
             }
         }
     } else {
-        qDebug() << fileName << " could not be opened!";
+        qCDebug(KALZIUM_LIBSCIENCE_LOG) << fileName << " could not be opened!";
     }
 
-    // Find the system defined aliases    
+    // Find the system defined aliases
     // Open the file
     fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("libkdeedu/data/symbols.csv"));
     QFile file2(fileName);
 
     // Check file validity
-    if (!(!file2.open(QIODevice::ReadOnly | QIODevice::Text))) {
-        qDebug() << fileName << " opened";
+    if (file2.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        qCDebug(KALZIUM_LIBSCIENCE_LOG) << fileName << " opened";
         QTextStream in(&file2);
 
         // Get all shortForms and fullForms in the file.
@@ -404,7 +397,7 @@ QString MoleculeParser::expandTerm (const QString& _group)
             QString line = in.readLine();
             shortForm = line.section(',', 0, 0);
             shortForm.remove(QChar('\"'));
-            fullForm  = line.section(',', 1, 1);
+            fullForm = line.section(',', 1, 1);
             fullForm.remove(QChar('\"'));
 
             if (shortForm == _group) {
@@ -413,7 +406,7 @@ QString MoleculeParser::expandTerm (const QString& _group)
             }
         }
     } else {
-        qDebug() << fileName << " could not be opened!";
+        qCDebug(KALZIUM_LIBSCIENCE_LOG) << fileName << " could not be opened!";
     }
 
     // Sample expansions, work even when file is not found, testing purposes
