@@ -4,9 +4,9 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include "elementparser.h"
-#include "element.h"
 #include "chemicaldataobject.h"
+#include "element.h"
+#include "elementparser.h"
 #include <QDebug>
 #include <iostream>
 
@@ -17,7 +17,7 @@ int main(int argc, char *argv[])
         return 1;
     }
 
-    ElementSaxParser * parser = new ElementSaxParser();
+    auto parser = new ElementSaxParser();
     QFile xmlFile(argv[1]);
 
     QXmlInputSource source(&xmlFile);
@@ -26,16 +26,16 @@ int main(int argc, char *argv[])
     reader.setContentHandler(parser);
     reader.parse(source);
 
-    QList<Element*> v = parser->getElements();
+    const QList<Element *> v = parser->getElements();
 
     std::cout << "Found " << v.count() << " elements." << std::endl;
 
-    foreach (Element *e, v) {
+    for (Element *e : v) {
         if (e) {
-            QList<ChemicalDataObject> list = e->data();
+            const QList<ChemicalDataObject> list = e->data();
 
-            //Test: give me all data available
-            foreach (const ChemicalDataObject &o, list) {
+            // Test: give me all data available
+            for (const ChemicalDataObject &o : list) {
                 QString unit = o.unitAsString();
                 if (unit == QLatin1String("bo:noUnit")) {
                     unit = QLatin1String("");
