@@ -16,22 +16,35 @@ class IsotopeScene : public QGraphicsScene
     Q_OBJECT
 
 public:
-    explicit IsotopeScene(QObject * parent = nullptr);
-    virtual ~IsotopeScene();
+    explicit IsotopeScene(QObject *parent, int mode);
+    ~IsotopeScene() override;
 
-    void updateContextHelp(IsotopeItem * item);
+    void updateContextHelp(IsotopeItem *item);
 
 private:
-    void drawIsotopes(void);
+    void initialize();
 
-    //the size of each item
+private:
+    void drawIsotopes();
+
+    // the size of each item
     int m_itemSize;
+    int m_mode;
 
-    ///this group stores all IsotopeItems
+    /// this group stores all IsotopeItems
     QGraphicsItemGroup *m_isotopeGroup;
 
-signals:
+public:
+    int mode() const
+    {
+        return m_mode;
+    }
+
+Q_SIGNALS:
     void itemSelected(IsotopeItem *item);
+
+public:
+    void setMode(int mode);
 };
 
 #endif // ISOTOPESCENE_H
