@@ -8,8 +8,11 @@
 
 #include "kalziumdataobject.h"
 #include "search.h"
+#include "colorutils.h"
 
 #include <KLocalizedString>
+#include <QGuiApplication>
+#include <QPalette>
 
 #include <prefs.h>
 
@@ -136,20 +139,7 @@ QBrush KalziumElementProperty::getElementBrush(int el)
     if (m_currentScheme == 2) {
         elementBrush = scheme()->elementBrush(el);
     } else {
-        // add a nice gradient
-        QColor color = getElementColor(el);
-        QLinearGradient grad(QPointF(0, 0), QPointF(0, 40));
-        grad.setColorAt(0, color);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        qreal h, s, v, a;
-#else
-        float h, s, v, a;
-#endif
-        color.getHsvF(&h, &s, &v, &a);
-        color.setHsvF(h, s, v * 0.7, a);
-        grad.setColorAt(1, color);
-
-        elementBrush = QBrush(grad);
+        return ColorUtils::tintWithAlpha(qGuiApp->palette().color(QPalette::Normal, QPalette::Window), getElementColor(el), 0.2);
     }
 
     return elementBrush;
@@ -157,19 +147,19 @@ QBrush KalziumElementProperty::getElementBrush(int el)
 
 QColor KalziumElementProperty::getTextColor(int el) const
 {
-    return scheme()->textColor(el);
+    return ColorUtils::contrastColor(scheme()->elementBrush(el).color());
 }
 
 QColor KalziumElementProperty::getBorderColor(int el) const
 {
     // Show scheme color as border when gradients are selected.
     if (m_currentGradient != NOGRADIENT) {
-        return scheme()->elementBrush(el).color();
+        return ColorUtils::contrastColor(scheme()->elementBrush(el).color());
     }
 
     // Transparent Borders don't make sens.
     if (getTextColor(el) == QColor(Qt::transparent)) {
-        return {Qt::black};
+        return ColorUtils::contrastColor({Qt::black});
     }
 
     return getTextColor(el);
