@@ -7,19 +7,18 @@
 #include "statemachine.h"
 
 StateSwitcher::StateSwitcher(QStateMachine *machine)
-        : QState(machine)
+    : QState(machine)
 {
 }
 
-void StateSwitcher::addState(QState *state, QAbstractAnimation *animation, const int &id)
+void StateSwitcher::addState(QState *state, QAbstractAnimation *animation, int id)
 {
-    StateSwitchTransition *trans = new StateSwitchTransition(id);
+    auto trans = new StateSwitchTransition(id);
     trans->setTargetState(state);
     addTransition(trans);
     trans->addAnimation(animation);
 }
 
-
 void StateSwitcher::switchToState(int n)
 {
     machine()->postEvent(new StateSwitchEvent(n));
