@@ -11,7 +11,7 @@
 #include <QObject>
 
 #include "element.h"
-//class Element;
+// class Element;
 
 /**
  * Represent a search.
@@ -26,11 +26,7 @@ public:
     /**
      * The kind of search we can perform
      */
-    enum SearchKind {
-        SearchByName = 0x01,
-        SearchBySymbol = 0x02,
-        SearchAll = 0xFF
-    };
+    enum SearchKind { SearchByName = 0x01, SearchBySymbol = 0x02, SearchAll = 0xFF };
 
     /**
      * Construct a new empty search.
@@ -56,12 +52,12 @@ public:
     /**
      * @return the found elements
      */
-    const QList<Element*>& foundElements() const;
+    const QList<Element *> &foundElements() const;
 
     /**
      * @return whether the element @p el matches the search
      */
-    bool matches(Element* el) const;
+    bool matches(Element *el) const;
 
     /**
      * @return whether the element @p el matches the search
@@ -74,13 +70,13 @@ public Q_SLOTS:
      * Search the @p text by looking at the element using the
      * specified @p kind
      */
-    void doSearch(const QString& text, SearchKind kind);
+    void doSearch(const QString &text, SearchKind kind);
     /**
      * Reset the current search (and put it not active).
      */
     void resetSearch();
 
-signals:
+Q_SIGNALS:
     /**
      * The current search has changed (ie the found elements have
      * changed)
@@ -92,12 +88,12 @@ signals:
     void searchReset();
 
 private:
-    bool m_isActive;
+    bool m_isActive = false;
 
     QString m_searchText;
     SearchKind m_searchKind;
 
-    QList<Element*> m_foundElements;
+    QList<Element *> m_foundElements;
 };
 
 #endif // KALZIUMSEARCH_H
