@@ -14,14 +14,14 @@
 
 #include <QDebug>
 #include <QFileInfo>
-#include <QGLFormat>
 #include <QUrl>
 
+#include <KIO/FileCopyJob>
 #include <KIO/Job>
 #include <KJob>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KNS3/QtQuickDialogWrapper>
+#include <KNSWidgets/Dialog>
 
 #include "iowrapper.h"
 
@@ -47,11 +47,6 @@ MoleculeDialog::MoleculeDialog(QWidget *parent)
     , m_path(QString())
     , m_periodicTable(nullptr)
 {
-    // use multi-sample (anti-aliased) OpenGL if available
-    QGLFormat defFormat = QGLFormat::defaultFormat();
-    defFormat.setSampleBuffers(true);
-    QGLFormat::setDefaultFormat(defFormat);
-
     setWindowTitle(i18nc("@title:window", "Molecular Editor"));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
     QWidget *mainWidget = new QWidget(this);
@@ -253,27 +248,23 @@ void MoleculeDialog::slotDownloadNewStuff()
 {
     qDebug() << "Kalzium new stuff";
 
-    KNS3::QtQuickDialogWrapper *dialog = new KNS3::QtQuickDialogWrapper(QStringLiteral("kalzium.knsrc"), this);
+    KNSWidgets::Dialog *dialog = new KNSWidgets::Dialog(QStringLiteral("kalzium.knsrc"), this);
     dialog->open();
-    connect(dialog, &KNS3::QtQuickDialogWrapper::closed, this, [this, dialog] {
+    connect(dialog, &KNSWidgets::Dialog::finished, this, [this, dialog] {
         // list of changed entries
         QString destinationDir = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
         QDir dir(destinationDir);
         if (!dir.exists()) {
             destinationDir = QDir::homePath();
         }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        const QList<KNSCore::EntryInternal> entries = dialog->changedEntries();
-#else
         const QList<KNSCore::Entry> entries = dialog->changedEntries();
-#endif
         bool anyError = false;
         bool anySuccess = false;
         bool moreOneInstalledFile = false;
         QString exactlyOneFile;
         foreach (const auto &entry, entries) {
             // care only about installed ones
-            if (entry.status() == KNS3::Entry::Installed) {
+            if (entry.status() == KNSCore::Entry::Installed) {
                 qDebug() << "Changed Entry: " << entry.installedFiles();
                 foreach (const QString &origFile, entry.installedFiles()) {
                     const QString destFile = destinationDir + '/' + QFileInfo(origFile).fileName();
